import { __decorate, __param } from 'tslib';
import { ɵɵdefineInjectable, Injectable, Inject, forwardRef, HostListener, Directive, Input, Component, ViewChild, NgModule } from '@angular/core';
import { BaseWidget, NgAisInstantSearch, NgAisModule } from 'angular-instantsearch';
import { connectToggleRefinement, connectMenu, connectPagination } from 'instantsearch.js/es/connectors';
import { MatSelectModule } from '@angular/material/select';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import { MatPaginatorModule } from '@angular/material/paginator';
import { CommonModule } from '@angular/common';

let AlgoliaService = class AlgoliaService {
    constructor() {
    }
};
AlgoliaService.ɵprov = ɵɵdefineInjectable({ factory: function AlgoliaService_Factory() { return new AlgoliaService(); }, token: AlgoliaService, providedIn: "root" });
AlgoliaService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], AlgoliaService);

const connectRefresh = (renderFn, unmountFn) => (widgetParams = {}) => ({
    init() {
        renderFn({
            refresh() {
            }
        }, true);
    },
    render({ instantSearchInstance }) {
        const refresh = instantSearchInstance.refresh.bind(instantSearchInstance);
        renderFn({ refresh }, false);
    },
    dispose() {
        unmountFn();
    }
});
const ɵ0 = connectRefresh;
let MatAlgoliaRefreshDirective = class MatAlgoliaRefreshDirective extends BaseWidget {
    constructor(instantSearchParent) {
        super('Refresh');
        this.instantSearchParent = instantSearchParent;
    }
    ngOnInit() {
        this.createWidget(connectRefresh, {});
        super.ngOnInit();
    }
    onClick() {
        console.log('click');
        this.state.refresh();
    }
};
MatAlgoliaRefreshDirective.ctorParameters = () => [
    { type: NgAisInstantSearch, decorators: [{ type: Inject, args: [forwardRef(() => NgAisInstantSearch),] }] }
];
__decorate([
    HostListener('click')
], MatAlgoliaRefreshDirective.prototype, "onClick", null);
MatAlgoliaRefreshDirective = __decorate([
    Directive({
        selector: '[matAlgoliaRefresh]'
    }),
    __param(0, Inject(forwardRef(() => NgAisInstantSearch)))
], MatAlgoliaRefreshDirective);

let MatAlgoliaToggleComponent = class MatAlgoliaToggleComponent extends BaseWidget {
    constructor(instantSearchParent) {
        super('MatAlgoliaToggleComponent');
        this.instantSearchParent = instantSearchParent;
    }
    ngOnInit() {
        this.createWidget(connectToggleRefinement, {
            // instance options
            attribute: this.attribute
        });
        super.ngOnInit();
    }
    onChange($event) {
        console.log('onChange', $event);
        this.state.refine(this.state.value);
        // this.state.refine($event.checked);
    }
};
MatAlgoliaToggleComponent.ctorParameters = () => [
    { type: NgAisInstantSearch, decorators: [{ type: Inject, args: [forwardRef(() => NgAisInstantSearch),] }] }
];
__decorate([
    Input()
], MatAlgoliaToggleComponent.prototype, "attribute", void 0);
__decorate([
    Input()
], MatAlgoliaToggleComponent.prototype, "label", void 0);
__decorate([
    Input()
], MatAlgoliaToggleComponent.prototype, "color", void 0);
MatAlgoliaToggleComponent = __decorate([
    Component({
        selector: 'mat-algolia-toggle',
        template: "<mat-slide-toggle (change)=\"onChange($event)\"\n                  *ngIf=\"state?.value\"\n                  [checked]=\"state?.value?.isRefined\">\n  {{ label || state?.value?.name}}\n  <span *ngIf=\"!state?.value?.isRefined\">({{state?.value?.count}})</span>\n</mat-slide-toggle>\n",
        styles: [""]
    }),
    __param(0, Inject(forwardRef(() => NgAisInstantSearch)))
], MatAlgoliaToggleComponent);

let MatAlgoliaMenuSelectComponent = class MatAlgoliaMenuSelectComponent extends BaseWidget {
    constructor(instantSearchParent) {
        super('MatAlgoliaMenuSelectComponent');
        this.instantSearchParent = instantSearchParent;
    }
    ngOnInit() {
        this.createWidget(connectMenu, { attribute: this.attribute });
        super.ngOnInit();
    }
};
MatAlgoliaMenuSelectComponent.ctorParameters = () => [
    { type: NgAisInstantSearch, decorators: [{ type: Inject, args: [forwardRef(() => NgAisInstantSearch),] }] }
];
__decorate([
    Input()
], MatAlgoliaMenuSelectComponent.prototype, "attribute", void 0);
MatAlgoliaMenuSelectComponent = __decorate([
    Component({
        selector: 'mat-algolia-menu-select',
        template: "<select\n  (change)=\"state.refine($event.target.value)\"\n  class=\"menu-select\"\n>\n  <option\n    *ngFor=\"let item of state.items\"\n    [selected]=\"item.isRefined\"\n    [value]=\"item.value\"\n  >\n    {{item.label}}\n  </option>\n</select>\n",
        styles: [""]
    }),
    __param(0, Inject(forwardRef(() => NgAisInstantSearch)))
], MatAlgoliaMenuSelectComponent);

let MatAlgoliaPaginationComponent = class MatAlgoliaPaginationComponent extends BaseWidget {
    constructor(instantSearchParent) {
        super('MatAlgoliaPaginationComponent');
        this.instantSearchParent = instantSearchParent;
        this.items = [
            { label: '1 hits per page', value: 10, default: true },
            { label: '2 hits per page', value: 15 },
            { label: '2 hits per page', value: 25 },
            { label: '2 hits per page', value: 50 }
        ];
    }
    ngOnInit() {
        this.createWidget(connectPagination, {
        // instance options
        });
        super.ngOnInit();
    }
    onPageChanged(pageEvent, hpp) {
        console.log('onPageChanged', pageEvent, this.pageSize, pageEvent.pageSize);
        if (this.pageSize !== pageEvent.pageSize) {
            console.log('refining', this.pageSize, pageEvent.pageSize);
            this.pageSize = pageEvent.pageSize;
            hpp.state.refine(this.pageSize);
        }
        if (pageEvent.pageIndex !== pageEvent.previousPageIndex) {
            this.state.refine(this.state.currentRefinement + (pageEvent.pageIndex > pageEvent.previousPageIndex ? 1 : -1));
        }
    }
    getDefaultPageSize(hpp) {
        // this.pageSize = hpp.state.items.filter(item => item.default === true).map(item => item.value)[0];
        // return this.pageSize;
        return hpp.state.items.filter(item => item.default === true).map(item => item.value)[0];
    }
    getPageSizeOptions(hpp) {
        if (hpp && hpp.state.items) {
            // console.log('page size options', hpp.state.items.map(item => item.value));
            return hpp.state.items.map(item => item.value);
        }
        else {
            return 0;
        }
    }
};
MatAlgoliaPaginationComponent.ctorParameters = () => [
    { type: NgAisInstantSearch, decorators: [{ type: Inject, args: [forwardRef(() => NgAisInstantSearch),] }] }
];
__decorate([
    ViewChild('hpp')
], MatAlgoliaPaginationComponent.prototype, "hitsPerPage", void 0);
MatAlgoliaPaginationComponent = __decorate([
    Component({
        selector: 'mat-algolia-pagination',
        template: "<ais-hits-per-page #hpp [items]=\"items\"\n                   style=\"display: none\"\n></ais-hits-per-page>\n<mat-paginator (page)=\"onPageChanged($event,hpp)\"\n               [length]=\"state.nbHits\"\n               [pageSizeOptions]=\"getPageSizeOptions(hpp)\"\n               [pageSize]=\"getDefaultPageSize(hpp)\">\n</mat-paginator>\n",
        styles: [""]
    }),
    __param(0, Inject(forwardRef(() => NgAisInstantSearch)))
], MatAlgoliaPaginationComponent);

const components = [
    MatAlgoliaRefreshDirective,
    MatAlgoliaToggleComponent,
    MatAlgoliaMenuSelectComponent,
    MatAlgoliaPaginationComponent
];
const directives = [MatAlgoliaRefreshDirective];
let MatAlgoliaModule = class MatAlgoliaModule {
};
MatAlgoliaModule = __decorate([
    NgModule({
        declarations: [
            ...components,
            ...directives
        ],
        imports: [
            // Angular
            CommonModule,
            // Angular Material
            MatSelectModule,
            MatSlideToggleModule,
            MatPaginatorModule,
            // Algolia
            NgAisModule
        ],
        exports: [
            ...components,
            ...directives
        ]
    })
], MatAlgoliaModule);

/*
 * Public API Surface of algolia
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AlgoliaService, MatAlgoliaMenuSelectComponent, MatAlgoliaModule, MatAlgoliaPaginationComponent, MatAlgoliaRefreshDirective, MatAlgoliaToggleComponent, ɵ0, MatAlgoliaRefreshDirective as ɵa, MatAlgoliaToggleComponent as ɵb, MatAlgoliaMenuSelectComponent as ɵc, MatAlgoliaPaginationComponent as ɵd };
//# sourceMappingURL=angular-material-extensions-algolia.js.map
